# Caching for PyTerrier

`pyterrier-caching` provides several components for caching intermediate results.

The right component will depend on your use case.

## Installation

Install this package using pip:

```bash
pip install pyterrier-caching
```

## Documentation

[Full Documention](https://pyterrier.readthedocs.io/en/latest/ext/pyterrier-caching/index.html)

Overview:
 - Cache scorer/reranker results with [`ScorerCache`](https://pyterrier.readthedocs.io/en/latest/ext/pyterrier-caching/scorer-cache.html)
 - Cache retriever results with [`RetrieverCache`](https://pyterrier.readthedocs.io/en/latest/ext/pyterrier-caching/retriever-cache.html)
 - Cache indexing streams with [`IndexerCache`](https://pyterrier.readthedocs.io/en/latest/ext/pyterrier-caching/indexer-cache.html)
